package com.huijy.management.mapper;

import java.util.List;
import com.huijy.management.domain.MarkerContent;

/**
 * 标记物内容中间Mapper接口
 *
 * @author luobo
 * @date 2021-10-10
 */
public interface MarkerContentMapper
{
    /**
     * 查询标记物内容中间
     *
     * @param markerContent 标记物内容中间主键
     * @return 标记物内容中间
     */
    public MarkerContent selectMarkerContentByMarkerContent(Long markerContent);

    /**
     * 查询标记物内容中间列表
     *
     * @param markerContent 标记物内容中间
     * @return 标记物内容中间集合
     */
    public List<MarkerContent> selectMarkerContentList(MarkerContent markerContent);

    /**
     * 新增标记物内容中间
     *
     * @param markerContent 标记物内容中间
     * @return 结果
     */
    public int insertMarkerContent(MarkerContent markerContent);

    /**
     * 修改标记物内容中间
     *
     * @param markerContent 标记物内容中间
     * @return 结果
     */
    public int updateMarkerContent(MarkerContent markerContent);

    /**
     * 删除标记物内容中间
     *
     * @param markerContent 标记物内容中间主键
     * @return 结果
     */
    public int deleteMarkerContentByMarkerContent(Long markerContent);

    /**
     * 批量删除标记物内容中间
     *
     * @param markerContents 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteMarkerContentByMarkerContents(Long[] markerContents);


    List<Long> selectContentIdListByMarkerId(Long markerId);

    Integer deleteMarkerContentByMarkerId(Long markerId);
}
